@@ -1,6 +1,7 @@
 from urllib.parse import quote
 
 import requests
+
 from roulette_russe.Scraper import Scraper
 
 
@@ -12,10 +13,12 @@ class TwitterScraper(Scraper):
         super(TwitterScraper, self).__init__(input_config, output_datasets, rr)
 
     def get_guest_token(self):
+        ua = self.get_laptop_user_agent()
+        print("UA used to renew guest token for twitter: ", ua)
         self.guest_token_number_of_uses += 1
-        if self.guest_token_number_of_uses > 10:
+        if self.guest_token_number_of_uses > 30:
             r = requests.get('https://twitter.com/CNBC', proxies=self.get_proxies(), headers={
-                'User-Agent': self.get_mobile_user_agent()
+                'User-Agent': ua
             })
             self.guest_token_number_of_uses = 1
             self.guest_token = r.text.split('decodeURIComponent("gt=')[1].split(';')[0]
@@ -23,19 +26,27 @@ class TwitterScraper(Scraper):
 
     def get_num_id_from_username(self, username):
         print(username)
-        r = requests.get('https://api.twitter.com/1.1/search/typeahead.json?q=' + username, proxies=self.get_proxies(), headers={
-            'User-Agent': self.get_laptop_user_agent(),
-            'x-guest-token': self.get_guest_token(),
-            'authorization': 'Bearer AAAAAAAAAAAAAAAAAAAAANRILgAAAAAAnNwIzUejRCOuH5E6I8xnZz4puTs%3D1Zv7ttfk8LF81IUq16cHjhLTvJu4FA33AGWWjCpTnA'
-        })
+        r = requests.get('https://api.twitter.com/1.1/search/typeahead.json?q=' + username, proxies=self.get_proxies(),
+                         headers={
+                             'User-Agent': self.get_laptop_user_agent(),
+                             'x-guest-token': self.get_guest_token(),
+                             'authorization': 'Bearer AAAAAAAAAAAAAAAAAAAAANRILgAAAAAAnNwIzUejRCOuH5E6I8xnZz4puTs%3D1Zv7ttfk8LF81IUq16cHjhLTvJu4FA33AGWWjCpTnA'
+                         })
         return str(r.json()['users'][0]['id'])
 
     def get_profile_data(self, twitter_numerical_id):
-        r = requests.get('https://api.twitter.com/2/timeline/profile/' + twitter_numerical_id + '.json', headers={
-            'User-Agent': self.get_mobile_user_agent(),
-            'x-guest-token': self.get_guest_token(),
-            'authorization': 'Bearer AAAAAAAAAAAAAAAAAAAAANRILgAAAAAAnNwIzUejRCOuH5E6I8xnZz4puTs%3D1Zv7ttfk8LF81IUq16cHjhLTvJu4FA33AGWWjCpTnA'
-        })
+        while 1:
+            try:
+                r = requests.get('https://api.twitter.com/2/timeline/profile/' + twitter_numerical_id + '.json',
+                                 headers={
+                                     'User-Agent': self.get_mobile_user_agent(),
+                                     'x-guest-token': self.get_guest_token(),
+                                     'authorization': 'Bearer AAAAAAAAAAAAAAAAAAAAANRILgAAAAAAnNwIzUejRCOuH5E6I8xnZz4puTs%3D1Zv7ttfk8LF81IUq16cHjhLTvJu4FA33AGWWjCpTnA'
+                                 })
+                break
+            except IndexError as e:
+                print('TWITTER TRIED TO BLOCK ME')
+                continue
         profile_data = r.json()['globalObjects']['users'][twitter_numerical_id]
         return {
             'twitter_internal_id': profile_data['id_str'],
@@ -52,15 +63,19 @@ class TwitterScraper(Scraper):
         tweets_list = []
         cursor_query = ''
         while 1:
-            r = requests.get(
-                quote(
-                    'https://api.twitter.com/2/timeline/profile/' + twitter_numerical_id + '.json?include_profile_interstitial_type=1&include_blocking=1&include_blocked_by=1&include_followed_by=1&include_want_retweets=1&include_mute_edge=1&include_can_dm=1&include_can_media_tag=1&skip_status=1&cards_platform=Web-12&include_cards=1&include_ext_alt_text=true&include_quote_count=true&include_reply_count=1&tweet_mode=extended&include_entities=true&include_user_entities=true&include_ext_media_color=true&include_ext_media_availability=true&send_error_codes=true&simple_quoted_tweet=true&include_tweet_replies=false&userId=' + twitter_numerical_id + '&count=20' + cursor_query,
-                    safe='/:?=&'), proxies=self.get_proxies(),
-                headers={
-                    'User-Agent': self.get_mobile_user_agent(),
-                    'x-guest-token': self.get_guest_token(),
-                    'authorization': 'Bearer AAAAAAAAAAAAAAAAAAAAANRILgAAAAAAnNwIzUejRCOuH5E6I8xnZz4puTs%3D1Zv7ttfk8LF81IUq16cHjhLTvJu4FA33AGWWjCpTnA'
-                })
+            try:
+                r = requests.get(
+                    quote(
+                        'https://api.twitter.com/2/timeline/profile/' + twitter_numerical_id + '.json?include_profile_interstitial_type=1&include_blocking=1&include_blocked_by=1&include_followed_by=1&include_want_retweets=1&include_mute_edge=1&include_can_dm=1&include_can_media_tag=1&skip_status=1&cards_platform=Web-12&include_cards=1&include_ext_alt_text=true&include_quote_count=true&include_reply_count=1&tweet_mode=extended&include_entities=true&include_user_entities=true&include_ext_media_color=true&include_ext_media_availability=true&send_error_codes=true&simple_quoted_tweet=true&include_tweet_replies=false&userId=' + twitter_numerical_id + '&count=20' + cursor_query,
+                        safe='/:?=&'), proxies=self.get_proxies(),
+                    headers={
+                        'User-Agent': self.get_mobile_user_agent(),
+                        'x-guest-token': self.get_guest_token(),
+                        'authorization': 'Bearer AAAAAAAAAAAAAAAAAAAAANRILgAAAAAAnNwIzUejRCOuH5E6I8xnZz4puTs%3D1Zv7ttfk8LF81IUq16cHjhLTvJu4FA33AGWWjCpTnA'
+                    })
+            except IndexError as e:
+                print('TWITTER TRIED TO BLOCK ME')
+                continue
             tweets = r.json()['globalObjects']['tweets']
             if tweets == {}:
                 break
@@ -98,4 +113,3 @@ class TwitterScraper(Scraper):
 
     def quality_check(self):
         pass
-
